import requests
import uuid
from pyt2s.service import Service

class IBM_Watson(Service):
    
    __validNames__ = [ 'en-GB_CharlotteV3Voice', 'en-GB_JamesV3Voice', 'en-GB_KateV3Voice', 'en-AU_JackExpressive', 'en-AU_HeidiExpressive', 'en-US_AllisonV3Voice', 
        'en-US_AllisonExpressive', 'en-US_EmilyV3Voice', 'en-US_EmmaExpressive', 'en-US_HenryV3Voice', 'en-US_KevinV3Voice', 'en-US_LisaV3Voice', 
        'en-US_LisaExpressive', 'en-US_MichaelV3Voice', 'en-US_MichaelExpressive', 'en-US_OliviaV3Voice', 'nl-NL_MerelV3Voice', 'fr-FR_NicolasV3Voice', 
        'fr-FR_ReneeV3Voice', 'fr-CA_LouiseV3Voice', 'de-DE_BirgitV3Voice', 'de-DE_DieterV3Voice', 'de-DE_ErikaV3Voice', 'it-IT_FrancescaV3Voice', 
        'ja-JP_EmiV3Voice', 'ko-KR_JinV3Voice', 'pt-BR_IsabelaV3Voice', 'es-ES_EnriqueV3Voice', 'es-ES_LauraV3Voice', 'es-LA_SofiaV3Voice', 'es-US_SofiaV3Voice' ]

    __session__ = requests.session()
    __url1__ = 'https://www.ibm.com/demos/live/tts-demo/api/tts/session'   
    __url2__ = 'https://www.ibm.com/demos/live/tts-demo/api/tts/store'   
    __url3__ = 'https://www.ibm.com/demos/live/tts-demo/api/tts/newSynthesizer'

    __headers__ = {
        'Origin': 'https://www.ibm.com',
        'Referer': 'https://www.ibm.com/demos/live/tts-demo/self-service/home',
        'Accept': 'application/json, text/plain, */*',
    }

    def requestTTS(self, text: str, voice = 'en-GB_CharlotteV3Voice'):
        super().requestTTS(text, voice)
        self.__session__.post(self.__url1__, headers=self.__headers__)
        id = str(uuid.uuid4())    
        jsonPayload = {"ssmlText": f"<prosody pitch=\"0%\" rate=\"-0%\">{text}</prosody>", "sessionID": id}   
        self.__session__.post(self.__url2__, data=jsonPayload, headers=self.__headers__)
        res = self.__session__.get(self.__url3__, params={'voice' : voice,'id': id})
        return res.content


import requests
from pyt2s.service import Service

class StreamElements(Service):

    __validNames__ = [ 'Brian', 'Amy', 'Emma', 'Geraint', 'Russell', 'Nicole', 'Joey', 'Justin', 'Matthew', 'Ivy', 'Joanna', 'Kendra', 'Kimberly', 'Salli', 'Raveena', 'Zhiyu', 
        'Mads', 'Naja', 'Ruben', 'Lotte', 'Mathieu', 'Celine', 'Chantal', 'Hans', 'Marlene', 'Vicki', 'Aditi', 'Karl', 'Dora', 'Carla', 'Bianca', 'Giorgio', 
        'Takumi', 'Mizuki', 'Seoyeon', 'Liv', 'Ewa', 'Maja', 'Jacek', 'Jan', 'Ricardo', 'Vitoria', 'Cristiano', 'Ines', 'Carmen', 'Maxim', 'Tatyana', 'Enrique', 
        'Conchita', 'Mia', 'Miguel', 'Penelope', 'Astrid', 'Filiz', 'Gwyneth', 'en-US-Wavenet-A', 'en-US-Wavenet-B', 'en-US-Wavenet-C', 'en-US-Wavenet-D', 
        'en-US-Wavenet-E', 'en-US-Wavenet-F', 'en-US-Standard-B', 'en-US-Standard-C', 'en-US-Standard-D', 'en-US-Standard-E', 'en-GB-Standard-A', 'en-GB-Standard-B', 
        'en-GB-Standard-C', 'en-GB-Standard-D', 'en-GB-Wavenet-A', 'en-GB-Wavenet-B', 'en-GB-Wavenet-C', 'en-GB-Wavenet-D', 'en-AU-Standard-A', 'en-AU-Standard-B', 
        'en-AU-Wavenet-A', 'en-AU-Wavenet-B', 'en-AU-Wavenet-C', 'en-AU-Wavenet-D', 'en-AU-Standard-C', 'en-AU-Standard-D', 'en-IN-Wavenet-A', 'en-IN-Wavenet-B', 
        'en-IN-Wavenet-C', 'af-ZA-Standard-A', 'ar-XA-Wavenet-A', 'ar-XA-Wavenet-B', 'ar-XA-Wavenet-C', 'bg-bg-Standard-A', 'cmn-CN-Wavenet-A', 'cmn-CN-Wavenet-B', 
        'cmn-CN-Wavenet-C', 'cmn-CN-Wavenet-D', 'cs-CZ-Wavenet-A', 'da-DK-Wavenet-A', 'nl-NL-Standard-A', 'nl-NL-Wavenet-A', 'nl-NL-Wavenet-B', 'nl-NL-Wavenet-C', 
        'nl-NL-Wavenet-D', 'nl-NL-Wavenet-E', 'fil-PH-Wavenet-A', 'fi-FI-Wavenet-A', 'fr-FR-Standard-C', 'fr-FR-Standard-D', 'fr-FR-Wavenet-A', 'fr-FR-Wavenet-B', 
        'fr-FR-Wavenet-C', 'fr-FR-Wavenet-D', 'fr-CA-Standard-A', 'fr-CA-Standard-B', 'fr-CA-Standard-C', 'fr-CA-Standard-D', 'de-DE-Standard-A', 'de-DE-Standard-B', 
        'de-DE-Wavenet-A', 'de-DE-Wavenet-B', 'de-DE-Wavenet-C', 'de-DE-Wavenet-D', 'el-GR-Wavenet-A', 'hi-IN-Wavenet-A', 'hi-IN-Wavenet-B', 'hi-IN-Wavenet-C', 
        'hu-HU-Wavenet-A', 'is-is-Standard-A', 'id-ID-Wavenet-A', 'id-ID-Wavenet-B', 'id-ID-Wavenet-C', 'it-IT-Standard-A', 'it-IT-Wavenet-A', 'it-IT-Wavenet-B', 
        'it-IT-Wavenet-C', 'it-IT-Wavenet-D', 'ja-JP-Standard-A', 'ja-JP-Wavenet-A', 'ja-JP-Wavenet-B', 'ja-JP-Wavenet-C', 'ja-JP-Wavenet-D', 'ko-KR-Standard-A', 
        'ko-KR-Wavenet-A', 'lv-lv-Standard-A', 'nb-no-Wavenet-E', 'nb-no-Wavenet-A', 'nb-no-Wavenet-B', 'nb-no-Wavenet-C', 'nb-no-Wavenet-D', 'pl-PL-Wavenet-A', 
        'pl-PL-Wavenet-B', 'pl-PL-Wavenet-C', 'pl-PL-Wavenet-D', 'pt-PT-Wavenet-A', 'pt-PT-Wavenet-B', 'pt-PT-Wavenet-C', 'pt-PT-Wavenet-D', 'pt-BR-Standard-A', 
        'ru-RU-Wavenet-A', 'ru-RU-Wavenet-B', 'ru-RU-Wavenet-C', 'ru-RU-Wavenet-D', 'sr-rs-Standard-A', 'sk-SK-Wavenet-A', 'es-ES-Standard-A', 'sv-SE-Standard-A', 
        'tr-TR-Standard-A', 'tr-TR-Wavenet-A', 'tr-TR-Wavenet-B', 'tr-TR-Wavenet-C', 'tr-TR-Wavenet-D', 'tr-TR-Wavenet-E', 'uk-UA-Wavenet-A', 'vi-VN-Wavenet-A', 
        'vi-VN-Wavenet-B', 'vi-VN-Wavenet-C', 'vi-VN-Wavenet-D', 'Linda', 'Heather', 'Sean', 'Hoda', 'Naayf', 'Ivan', 'Herena', 'Tracy', 'Danny', 'Huihui', 'Yaoyao', 
        'Kangkang', 'HanHan', 'Zhiwei', 'Matej', 'Jakub', 'Guillaume', 'Michael', 'Karsten', 'Stefanos', 'Szabolcs', 'Andika', 'Heidi', 'Kalpana', 'Hemant', 'Rizwan', 
        'Filip', 'Lado', 'Valluvar', 'Pattara', 'An' ]

    __url1__ = 'https://api.streamelements.com/kappa/v2/speech?'

    def requestTTS(self, text: str, voice = 'Brian'):
        super().requestTTS(text, voice)
        params = {
            'voice': voice,
            'text': text
        }
        res = requests.get(self.__url1__, params)
        return res.content


import json
from pyt2s.service import Service
import requests

class Acapela(Service):

    __validNames__ = [ 'graham22k', 'harry22k', 'lucy22k', 'lucy_nt22k', 'peter22k', 'peter_nt22k', 'queenelizabeth22k', 'queenelizabeth_nt22k', 'rachel22k', 'rachel_nt22k', 
        'rosie22k', 'sophiabtob22k', 'sophiabtob_nt22k', 'rhona22k', 'rhona_nt22k', 'liam22k', 'lisa22k', 'lisa_nt22k', 'olivia22k', 'tyler22k', 'tyler_nt22k', 
        'deepa22k', 'deepa_nt22k', 'nizareng22k', 'nizareng_nt22k', 'darius22k', 'darius_nt22k', 'ella22k', 'emilioenglish22k', 'josh22k', 'karen22k', 'karen_nt22k', 
        'laura22k', 'laura_nt22k', 'lily22k', 'lily_nt22k', 'micah22k', 'rod22k', 'rod_nt22k', 'ryan22k', 'ryan_nt22k', 'saul22k', 'saul_nt22k', 'scott22k', 
        'sharon22k', 'sharon_nt22k', 'tamira22k', 'tamira_nt22k', 'taylor22k', 'taylor_nt22k', 'tracy22k', 'tracy_nt22k', 'valeriaenglish22k', 'will22k', 
        'will_nt22k', 'leila22k', 'leila_nt22k', 'jalal22k', 'jalal_nt22k', 'mehdi22k', 'mehdi_nt22k', 'nizar22k', 'nizar_nt22k', 'salma22k', 'salma_nt22k', 
        'laia22k', 'laia_nt22k', 'lulu22k', 'lulu_nt22k', 'eliska22k', 'eliska_nt22k', 'mette22k', 'mette_nt22k', 'rasmus22k', 'rasmus_nt22k', 'rikke22k', 
        'rikke_nt22k', 'daan22k', 'daan_nt22k', 'femke22k', 'femke_nt22k', 'jasmijn22k', 'jasmijn_nt22k', 'max22k', 'max_nt22k', 'tessabtob22k', 'tessabtob_nt22k', 
        'christinabtob22k', 'christinabtob_nt22k', 'jeroen22k', 'jeroen_nt22k', 'sofie22k', 'sofie_nt22k', 'zoe22k', 'zoe_nt22k', 'hanna22k', 'hanna_nt22k', 
        'hanus22k', 'hanus_nt22k', 'sanna22k', 'sanna_nt22k', 'alice22k', 'alice_nt22k', 'anais22k', 'anais_nt22k', 'anaisbtob22k', 'anaisbtob_nt22k', 'antoine22k', 
        'antoine_nt22k', 'bruno22k', 'bruno_nt22k', 'claire22k', 'claire_nt22k', 'constance22k', 'constance_nt22k', 'elise22k', 'julie22k', 'julie_nt22k', 'manon22k', 
        'manon_nt22k', 'margaux22k', 'margaux_nt22k', 'valentin22k', 'anthony22k', 'anthony_nt22k', 'louise22k', 'louise_nt22k', 'alice-be22k', 'alice-be_nt22k', 
        'anais-be22k', 'anais-be_nt22k', 'antoine-be22k', 'antoine-be_nt22k', 'bruno-be22k', 'bruno-be_nt22k', 'claire-be22k', 'claire-be_nt22k', 'elise-be22k', 
        'julie-be22k', 'julie-be_nt22k', 'manon-be22k', 'manon-be_nt22k', 'margaux-be22k', 'margaux-be_nt22k', 'valentin-be22k', 'andreas22k', 'andreas_nt22k', 
        'ankebtob22k', 'ankebtob_nt22k', 'claudia22k', 'claudia_nt22k', 'jonas22k', 'julia22k', 'julia_nt22k', 'klaus22k', 'klaus_nt22k', 'lea22k', 'sarah22k', 
        'sarah_nt22k', 'dimitris22k', 'dimitris_nt22k', 'alessio22k', 'aurora22k', 'barbarabtob22k', 'barbarabtob_nt22k', 'chiara22k', 'chiara_nt22k', 'fabiana22k', 
        'fabiana_nt22k', 'vittorio22k', 'vittorio_nt22k', 'sakura22k', 'sakura_nt22k', 'minji22k', 'minji_nt22k', 'bente22k', 'bente_nt22k', 'elias22k', 'emilie22k', 
        'ida22k', 'ida_nt22k', 'kari22k', 'kari_nt22k', 'olav22k', 'olav_nt22k', 'ania22k', 'ania_nt22k', 'gosia22k', 'gosia_nt22k', 'isabel22k', 'isabel_nt22k', 
        'gabriela22k', 'gabriela_nt22k', 'marcia22k', 'marcia_nt22k', 'sergio22k', 'sergio_nt22k', 'alyona22k', 'alyona_nt22k', 'lena22k', 'lena_nt22k', 
        'biera_hmm_22k', 'elle_hmm_22k', 'anabtob22k', 'anabtob_nt22k', 'antonio22k', 'antonio_nt22k', 'elenabtob22k', 'elenabtob_nt22k', 'ines22k', 'ines_nt22k', 
        'maria22k', 'maria_nt22k', 'emilio22k', 'rodrigo22k', 'rodrigo_nt22k', 'rosa22k', 'rosa_nt22k', 'valeria22k', 'elin22k', 'elin_nt22k', 'emil22k', 
        'emil_nt22k', 'emma22k', 'emma_nt22k', 'erik22k', 'erik_nt22k', 'filip22k', 'freja22k', 'kal22k', 'kal_nt22k', 'mia22k', 'mia_nt22k', 'samuel22k', 
        'samuel_nt22k', 'ipek22k', 'ipek_nt22k', 'zeynep22k', 'zeynep_nt22k' ]

    __session__ = requests.session()
    __url1__ = 'https://www.acapela-group.com/www/static/website/demoOptionsDef_voicedemo.php'
    __url2__ = 'https://h-ir-ssd-1.acapela-group.com/webservices/1-60-00/UrlMaker.json'

    __headers__ = {
        'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
        'Referer': 'https://www.acapela-group.com/demos/',
        'Origin': 'https://www.acapela-group.com/demos/',                             
    }

    def requestTTS(self, text: str, voice = 'sharon22k'):
        super().requestTTS(text, voice)
        res = self.__session__.get(self.__url1__, headers=self.__headers__)
        json_res = res.text.replace('var vaasOptions = ', '').replace('};', '}')
        json_res = json.loads(json_res)
        params = {
            'cl_login': json_res['login'],
            'cl_app': json_res['app'],
            'session_start': json_res['session']['start'],
            'session_time': json_res['session']['time'],
            'session_key': json_res['session']['key'],
            'req_voice': voice,
            'req_text': text
        }

        res = self.__session__.post(self.__url2__, params=params, headers=self.__headers__)
        res = self.__session__.get(res.json()['snd_url'])
        return res.content


class Service():

    __url1__ = ''
    __url2__ = ''

    __headers__ = {}

    __validNames__ = []

    def requestTTS(self, text: str, voice: str):
        if voice not in self.__validNames__:
            raise Exception('Not a valid name')


import requests
from pyt2s.service import Service

class StreamLabs(Service):
    
    __validNames__ = [ 'Brian', 'Amy', 'Emma', 'Geraint', 'Russell', 'Nicole', 'Joey', 'Justin', 'Matthew', 'Ivy', 'Joanna', 'Kendra', 'Kimberly', 'Salli', 'Raveena', 'Zeina', 
        'Zhiyu', 'Mads', 'Naja', 'Ruben', 'Lotte', 'Mathieu', 'Celine', 'Lea', 'Chantal', 'Hans', 'Marlene', 'Vicki', 'Aditi', 'Karl', 'Dora', 'Carla', 'Bianca', 
        'Giorgio', 'Takumi', 'Mizuki', 'Seoyeon', 'Liv', 'Ewa', 'Maja', 'Jacek', 'Jan', 'Ricardo', 'Camila', 'Vitoria', 'Cristiano', 'Ines', 'Carmen', 'Maxim', 
        'Tatyana', 'Enrique', 'Conchita', 'Lucia', 'Mia', 'Miguel', 'Lupe', 'Penelope', 'Astrid', 'Filiz', 'Gwyneth' ]
    
    __url1__ = 'https://streamlabs.com/polly/speak'
    
    __headers__ = {
        'Referer': 'https://streamlabs.com'
    }
    
    def requestTTS(self, text: str, voice = 'Brian'):
        super().requestTTS(text, voice)
        params = {
            'voice': voice,
            'text': text
        }
        res = requests.post(self.__url1__, params=params, headers=self.__headers__)
        mp3_url = res.json()['speak_url']
        res = requests.get(mp3_url)
        return res.content


import requests
import time
from pyt2s.service import Service

class Cepstral(Service):

    __validNames__ = [ 'Allison', 'Amy', 'Belle', 'Callie', 'Charlie', 'Dallas', 'Damien', 'David', 'Diane', 'Duchess', 'Emily', 'Linda', 'Robin', 'Shouty', 'Walter', 
        'William', 'Whispery', 'Lawrence', 'Millie', 'Duncan', 'Vittoria', 'Katrin', 'Matthias', 'Isabelle', 'Jean-Pierre', 'Alejandra', 'Miguel' ]

    __session__ = requests.session()

    __url1__ = 'https://www.cepstral.com/en/demos'
    __url2__ = 'https://www.cepstral.com/demos/createAudio.php?'
     
    def requestTTS(self, text: str, voice = 'Belle'):
        super().requestTTS(text, voice)
        params = {
            'voiceText': text,
            'voice': voice,
            'createTime': int(time.time() * 1000),
            'rate': 170,
            'pitch': 1,
            'sfx': 'none'
        }
        self.__session__.get(self.__url1__)
        res = self.__session__.get(self.__url2__, params=params)
        mp3_location = 'https://www.cepstral.com' + res.json()['mp3_loc']
        res = self.__session__.get(mp3_location)
        return res.content


import requests
from pyt2s.service import Service

class VoiceForge(Service):
    
    __validNames__ = [ 'Conrad', 'Designer', 'Diesel', 'Dog', 'Evilgenius', 'Frank', 'French-fry', 'Gregory', 'Jerkface', 'JerseyGirl', 'Kayla', 'Kevin', 
        'Kidaroo', 'Princess', 'RansomNote', 'Robot', 'Shygirl', 'Susan', 'Tamika', 'TopHat', 'Vixen', 'Vlad', 'Warren', 'Wiseguy', 'Zach', 'Obama' ]
    
    __url1__ = 'https://api.voiceforge.com/swift_engine?'
    
    __headers__ = {
        'HTTP_X_API_KEY': '8b3f76a8539',
    }
    
    def requestTTS(self, text: str, voice = 'Conrad'):
        super().requestTTS(text, voice)
        params = {
            'voice': voice,
            'msg': text,
            'email': 'null',
        }
        res = requests.get(self.__url1__, params=params, headers=self.__headers__)
        return res.content